<?php


namespace TDevAgency\Cms\Traits;

use Illuminate\Database\Eloquent\Builder;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Config;
use Illuminate\Support\Facades\Validator;
use Illuminate\Support\Facades\View;
use Illuminate\Support\Str;
use Mcamara\LaravelLocalization\Facades\LaravelLocalization;
use TDevAgency\Cms\Models\BaseModels\Post;
use TDevAgency\Cms\Models\BaseModels\PostLocalization;

trait PostHelper
{
    /**
     * @param Request $request
     * @param Post $post
     */
    public function postPrepare(Request $request, &$post)
    {
        foreach ($post->getFillable() as $field) {
            if ($request->has($field)) {
                $post->$field = $request->get($field);
            }
        }
        if (!in_array('slug', config('cms.excluded_components'))) {
            $slug = $request->get('localizations')[LaravelLocalization::getCurrentLocale()]['title'];
            if (!($request->exists('slug'))) {
                if (Post::where('slug', Str::slug($slug))->first()) {
                    $flag = true;
                    $count = 1;
                    while ($flag) {
                        if (Post::where('slug', Str::slug($slug) . '-' . $count)->first()) {
                            $count++;
                        } else {
                            $post->slug = Str::slug($slug . '-' . $count);
                            $flag = false;
                        }
                    }
                } else {
                    $post->slug = Str::slug($slug);
                }
            }
        }
    }

    /**
     *
     * @param $localizations
     * @param $post
     */
    public function saveLocalization($localizations, $post)
    {
        foreach ($localizations as $lang => $row) {
            PostLocalization::updateOrCreate(
                [
                    'post_id' => $post->id,
                    'lang' => $lang,
                ],
                [
                    'post_id' => $post->id,
                    'title' => $row['title'],
                    'description' => $row['description'],
                    'meta_title' => $row['meta_title'] ?? null,
                    'meta_description' => $row['meta_description'] ?? null,
                    'short_description' => $row['short_description'] ?? null,
                    'lang' => $lang,
                ]);
        }
    }

    /**
     * @param int $postId
     * @param array $additionalValidations
     * @return array
     */

    public function validatorsArray(int $postId = 0, $additionalValidations = [])
    {
        $validatorsArray = [
            'localizations.*.title' => 'required',
            'localizations.*.short_description' => 'required',
        ];

        if (!in_array('slug', Config::get('cms.excluded_components')) && $postId > 0) {

            $validatorsArray['slug'] = 'required|unique:posts,id,' . $postId;
        }

        if (!in_array('seo-block', Config::get('cms.excluded_components'))) {
            $validatorsArray['localizations.*.meta_title'] = 'required|max:80';
            $validatorsArray['localizations.*.meta_description'] = 'required|max:300';
        }

        return array_merge_recursive($validatorsArray, $additionalValidations);
    }


    /**
     * @param $postType
     * @param Request $request
     * @param array $actions
     * @return \Illuminate\Contracts\View\View
     */
    public function displayList($postType, Request $request, $actions = ['index' => 'cms.posts.index', 'edit' => 'cms.posts.edit', 'destroy' => 'cms.posts.destroy'])
    {

        $posts = Post::where('post_type', $postType)->with('adminLocalization');
        if ($request->query->has('q') && $request->query->get('q') !== '' && $request->query->get('q') !== null) {
            $postIds = PostLocalization::search($request->query->get('q'), function (Builder $q) {
                return $q->groupBy('post_id');
            })->get()->pluck('post_id');
            $posts = $posts->whereIn('id', $postIds);
        }

        $posts = $posts->paginate(15);
        return View::make('cms::admin.screens.posts.index')
            ->with('actions', $actions)
            ->with('posts', $posts);
    }
}
