<!DOCTYPE html>
<html lang="{{ str_replace('_', '-', app()->getLocale()) }}">
<head>
    <meta charset="utf-8">
    <meta http-equiv="X-UA-Compatible" content="IE=edge">
    <title>{{Breadcrumbs::pageTitle()}}</title>
    <link rel="shortcut icon" href="{{asset('cms/images/favicon.png')}}" type="image/x-icon">

    <meta name="csrf-token" content="{{ csrf_token() }}">
    <meta name="viewport" content="width=device-width, initial-scale=1">
    <link rel="stylesheet" href="{{mixCms('css/app.css', 'cms')}}">
    <link href="https://fonts.googleapis.com/css2?family=Roboto:wght@400;500;700;900&display=swap" rel="stylesheet"  crossorigin="anonymous">
    @stack('styles')
</head>
<body class="hold-transition sidebar-mini layout-fixed layout-navbar-fixed">
<!-- Site wrapper -->
<div class="wrapper" id="app">

    <!-- Navbar -->
    <nav class="main-header navbar navbar-expand navbar-white navbar-light">
        <!-- Left navbar links -->
        <ul class="navbar-nav">
            <li class="nav-item">
                <a class="nav-link" data-widget="pushmenu" href="#"><i class="fas fa-bars"></i></a>
            </li>
        </ul>

        <!-- Right navbar links -->
        <ul class="navbar-nav ml-auto">
        </ul>
    </nav>
    <!-- /.navbar -->
    <aside class="main-sidebar sidebar-dark-primary elevation-4">
        <!-- Brand Logo -->
        <a href="/" class="brand-link">
            <span class="brand-text font-weight-light">{{Config::get('app.name')}}</span>
        </a>

        <div class="sidebar">

            <!-- Sidebar Menu -->
            <nav class="mt-2">
                <ul class="nav nav-pills nav-sidebar flex-column" data-widget="treeview" role="menu"
                    data-accordion="false">
                    @php
                        $adminSidebar = Config::get('cms_admin_sidebar');
                        ksort($adminSidebar);
                    @endphp
                    @foreach($adminSidebar as $group)
                        @foreach($group as $name => $item)
                            @if(!in_array($name, Config::get('cms.excluded_screens')))
                                @component('cms::admin.components.sidebar.'. (isset($item['resource']) ? 'treeview' : 'item'))
                                    @slot('route', $item)
                                @endcomponent
                            @endif
                        @endforeach
                    @endforeach

                    {{-- Logout --}}
                    <li class="nav-item">
                        <form id="logout-form" action="{{ route('cms.logout') }}" method="post">
                            @csrf
                            <button class="nav-link">
                                <i class="nav-icon fas fa-sign-out-alt"></i>
                                <p>@lang('cms::sidebar.logout')</p>
                            </button>
                        </form>
                    </li>
                </ul>
            </nav>
            <!-- /.sidebar-menu -->
        </div>
        <!-- /.sidebar -->
    </aside>

    <div class="content-wrapper">
        <!-- Content Header (Page header) -->
        <section class="content-header">
            <div class="container-fluid">
                <div class="row mb-2 justify-content-between">
                    <div class="col-sm-auto">
                        <h1>{{Breadcrumbs::pageTitle()}}</h1>
                    </div>
                    <div class="col-sm-auto">
                        {!! Breadcrumbs::render() !!}
                    </div>
                </div>
            </div><!-- /.container-fluid -->
        </section>

        <!-- Main content -->
        <section class="content">
            <div class="container-fluid">
                @yield('content')
            </div>
        </section>
        <!-- /.content -->
    </div>

    <footer class="main-footer">
        <div class="float-right d-none d-sm-block">
            @lang('cms-fixed::admin.version', ['version' => '1.0.0'])
        </div>
        <strong>&copy; 2019-{{\Carbon\Carbon::now()->yearIso}}


            @if(!in_array('author-block', config('cms.excluded_components')))<a
                target="_blank"
                rel="noopener"
                href="https://tdev.agency">TDev Agency</a>@endif.</strong>
        @lang('cms-fixed::admin.all_rights_reserved')
    </footer>


    <files-manager get-action="{{route('files-manager.index')}}" component-name="modal"
                   store-action="{{route('files-manager.store')}}"></files-manager>
</div>
<script src="{{ route('files-manager.js') }}" crossorigin="anonymous"></script>
<script src="{{asset('ckeditor/ckeditor.js')}}" crossorigin="anonymous"></script>
<script src="{{mixCms('js/app.js')}}" crossorigin="anonymous"></script>

@if(File::exists(public_path('js/'. Config::get('cms.admin_components_js'))))
    <script src="{{mix('js/'.  Config::get('cms.admin_components_js'))}}"></script>
@endif
<script src="{{mixCms('js/vue.js')}}"  crossorigin="anonymous"></script>
@stack('scripts')
@if(Session::has('toast'))
    <!-- Toast -->
    <script>

    (function($) {
        $(document).Toasts('create', {
            title: '{!! Session::get('toast.title') !!}',
            position: 'bottomRight',
            autohide: true,
            delay: 5000,
            class: 'bg-{!! Session::get('toast.status') !!}',
            {{--body: '{!! Session::get('toast.body') !!}'--}}
        })
    })(jQuery, window)
    </script>
@endif
@if($errors->any())
    <script>
    (function($) {


        $(document).Toasts('create', {
            title: '{{ trans('cms::admin.validation_failed') }}',
            position: 'bottomRight',
            autohide: true,
            delay: 5000,
            class: 'bg-warning',
            {{--body: '{!! Session::get('toast.body') !!}'--}}
        })

        if (typeof Validator === 'undefined') {
            return;
        }
        @foreach($errors->getMessages() as $filedName => $error)
        Validator.errors.add({ field: '{!! inputKeyToName($filedName) !!}', msg: '{!! $error[0] !!}' });
        @endforeach
    })(jQuery, window)
    </script>
@endif
</body>
</html>
