@extends('cms::admin.layouts.auth')

@push('title', trans('cms::auth.sign_in'))

@section('content')
    <form action="{{route('cms.login')}}" method="post" @submit="validateBeforeSubmit">
        <div class="card-body login-card-body">
            @csrf
            @honeypot

            <div class="input-group mb-3">
                <input id="email"
                       type="email"
                       placeholder="@lang('cms::auth.email')"
                       data-vv-as="@lang('cms::auth.email')"
                       class="form-control @error('email') is-invalid @enderror" name="email"
                       :class="{'is-invalid': errors.has('email')}"
                       value="{{ old('email') }}"
                       v-validate="'required|email'"
                       autocomplete="new-password"
                       autofocus />
                <div class="input-group-append">
                    <div class="input-group-text">
                        <span class="fas fa-envelope"></span>
                    </div>
                </div>

                <div v-if="errors.has('email')" class="invalid-feedback" role="alert">
                    @{{ errors.first('email') }}
                </div>
                @error('email')
                <div class="invalid-feedback" role="alert">{{ $message }}</div>
                @enderror

            </div>
            <div class="input-group mb-3">
                <input id="password" type="password"
                       v-validate="'required'"
                       :class="{'is-invalid': errors.has('password')}"
                       class="form-control @error('password') is-invalid @enderror" name="password"
                       placeholder="@lang('cms::auth.password')"
                       data-vv-as="@lang('cms::auth.password')"
                       required
                       autocomplete="new-password">
                <div class="input-group-append">
                    <div class="input-group-text">
                        <span class="fas fa-lock"></span>
                    </div>
                </div>

                <div v-if="errors.has('password')" class="invalid-feedback" role="alert">
                    @{{ errors.first('password') }}
                </div>
                @error('password')
                <span class="invalid-feedback" role="alert">
                                        <strong>{{ $message }}</strong>
                                    </span>
                @enderror
            </div>
            <div class="row">
                <div class="col align-self-center">

                    <div class="custom-control custom-checkbox">
                        <input type="checkbox"
                               class="custom-control-input"
                               name="remember"
                               {{ old('remember') ? 'checked' : '' }}
                               id="remember_me">
                        <label class="custom-control-label form-check-label"
                               for="remember_me">@lang('cms::auth.remember_me')</label>
                    </div>
                </div>
                <!-- /.col -->
                <div class="col-12 col-md-6 text-right">
                    @if (Route::has('password.request'))
                        <a href="{{route('password.request')}}">@lang('cms::auth.i_forgot_password')</a>
                    @endif
                </div>
                <!-- /.col -->
            </div>

        </div>
        <div class="card-footer text-right">
            <button type="submit" class="btn btn-primary btn-block">@lang('cms::auth.sign_in')</button>
        </div>
    </form>
@endsection
