<?php

use Illuminate\Support\Facades\Route;
use Spatie\Honeypot\ProtectAgainstSpam;
use TDevAgency\Cms\Controllers\Admin\DashboardController;
use TDevAgency\Cms\Controllers\Admin\CategoriesController;
use TDevAgency\Cms\Controllers\Admin\InputsController;
use TDevAgency\Cms\Controllers\Admin\LogViewerController;
use TDevAgency\Cms\Controllers\Admin\PageController;
use TDevAgency\Cms\Controllers\Admin\PostsController;
use TDevAgency\Cms\Controllers\Admin\UsersController;
use TDevAgency\Cms\Controllers\Auth\ForgotPasswordController;
use TDevAgency\Cms\Controllers\Auth\LoginController;
use TDevAgency\Cms\Controllers\Auth\ResetPasswordController;
use TDevAgency\Cms\Middleware\AccessMiddleware;
use TDevAgency\Cms\Middleware\AuthenticateMiddleware;

Route::middleware(ProtectAgainstSpam::class)->group(function () {
    Route::get('login', [LoginController::class, 'showLoginForm'])->name('cms.login');
    Route::post('login', [LoginController::class, 'login'])->name('cms.login');
    Route::post('logout', [LoginController::class, 'logout'])->name('cms.logout');

// Password Reset Routes...
    Route::get('password/reset', [ForgotPasswordController::class, 'showLinkRequestForm'])->name('password.request');
    Route::post('password/email', [ForgotPasswordController::class, 'sendResetLinkEmail'])->name('password.email');
    Route::get('password/reset/{token}', [ResetPasswordController::class, 'showResetForm'])->name('password.reset');
    Route::post('password/reset', [ResetPasswordController::class, 'reset']);
});

Route::group(['middleware' => [
    AuthenticateMiddleware::class . ':admin_user',
    AccessMiddleware::class
], 'as' => 'cms.'], static function () {
    Route::get('/', [DashboardController::class, 'index'])->name('dashboard');
    Route::get('logs', [LogViewerController::class, 'index'])->name('logs');
    Route::resource('admin-users', UsersController::class);
    Route::resource('posts', PostsController::class);
    Route::resource('pages', PageController::class);
    Route::resource('categories', CategoriesController::class);

    Route::get('media', [DashboardController::class, 'media'])->name('media');

    if (File::exists(base_path('routes/admin.php'))) {
        require_once base_path('routes/admin.php');
    }

    Route::get('inputs', [InputsController::class, 'showInputsForm'])->name('inputs');
    Route::post('inputs', [InputsController::class, 'uploadInputsForm'])->name('upload');
});
